@@ -14,8 +14,6 @@ from .tfkeras import EfficientNetB3, EfficientNetB4, EfficientNetB5, EfficientNe
 
 from .layers import ClipBoxes, RegressBoxes, FilterDetections, wBiFPNAdd, BatchNormalization
 from .initializers import PriorProbability
-from .utils.anchors import anchors_for_shape
-import numpy as np
 
 w_bifpns = [64, 88, 112, 160, 224, 288, 384]
 image_sizes = [512, 640, 768, 896, 1024, 1280, 1408]
@@ -151,7 +149,7 @@ def build_wBiFPN(features, num_channels, id, freeze_bn=False):
     return P3_out, P4_out, P5_out, P6_out, P7_out
 
 
-def build_regress_head(width, depth, num_anchors=9, detect_quadrangle=False):
+def build_regress_head(width, depth, num_anchors=9):
     options = {
         'kernel_size': 3,
         'strides': 1,
@@ -170,14 +168,9 @@ def build_regress_head(width, depth, num_anchors=9, detect_quadrangle=False):
             **options
         )(outputs)
 
-    if detect_quadrangle:
-        outputs = layers.Conv2D(num_anchors * 9, **options)(outputs)
-        # (b, num_anchors_this_feature_map, 9)
-        outputs = layers.Reshape((-1, 9))(outputs)
-    else:
-        outputs = layers.Conv2D(num_anchors * 4, **options)(outputs)
-        # (b, num_anchors_this_feature_map, 4)
-        outputs = layers.Reshape((-1, 4))(outputs)
+    outputs = layers.Conv2D(num_anchors * 4, **options)(outputs)
+    # (b, num_anchors_this_feature_map, 4)
+    outputs = layers.Reshape((-1, 4))(outputs)
 
     return models.Model(inputs=inputs, outputs=outputs, name='box_head')
 
@@ -216,9 +209,7 @@ def build_class_head(width, depth, num_classes=20, num_anchors=9):
     return models.Model(inputs=inputs, outputs=outputs, name='class_head')
 
 
-def efficientdet(phi, num_classes=20, num_anchors=9, weighted_bifpn=False, freeze_bn=False,
-                 score_threshold=0.01,
-                 detect_quadrangle=False, anchor_parameters=None):
+def efficientdet(phi, num_classes=20, weighted_bifpn=False, freeze_bn=False, score_threshold=0.01):
     assert phi in range(7)
     input_size = image_sizes[phi]
     input_shape = (input_size, input_size, 3)
@@ -237,8 +228,8 @@ def efficientdet(phi, num_classes=20, num_anchors=9, weighted_bifpn=False, freez
     else:
         for i in range(d_bifpn):
             features = build_BiFPN(features, w_bifpn, i, freeze_bn=freeze_bn)
-    regress_head = build_regress_head(w_head, d_head, num_anchors=num_anchors, detect_quadrangle=detect_quadrangle)
-    class_head = build_class_head(w_head, d_head, num_classes=num_classes, num_anchors=num_anchors)
+    regress_head = build_regress_head(w_head, d_head)
+    class_head = build_class_head(w_head, d_head, num_classes=num_classes)
     regression = [regress_head(feature) for feature in features]
     regression = layers.Concatenate(axis=1, name='regression')(regression)
     classification = [class_head(feature) for feature in features]
@@ -247,25 +238,18 @@ def efficientdet(phi, num_classes=20, num_anchors=9, weighted_bifpn=False, freez
     model = models.Model(inputs=[image_input], outputs=[regression, classification], name='efficientdet')
 
     # apply predicted regression to anchors
-
-    # anchors_input = layers.Input((None, 4))
-    anchors = anchors_for_shape((input_size, input_size), anchor_params=anchor_parameters)
-    anchors_input = np.expand_dims(anchors, axis=0)
-    boxes = RegressBoxes(name='boxes')([anchors_input, regression[..., :4]])
+    # anchors = tf.tile(tf.expand_dims(tf.constant(anchors), axis=0), (tf.shape(regression)[0], 1, 1))
+    anchors_input = layers.Input((None, 4))
+    boxes = RegressBoxes(name='boxes')([anchors_input, regression])
     boxes = ClipBoxes(name='clipped_boxes')([image_input, boxes])
 
     # filter detections (apply NMS / score threshold / select top-k)
-    if detect_quadrangle:
-        detections = FilterDetections(
-            name='filtered_detections',
-            score_threshold=score_threshold,
-            detect_quadrangle=True
-        )([boxes, classification, regression[..., 4:8], regression[..., 8]])
-    else:
-        detections = FilterDetections(
-            name='filtered_detections',
-            score_threshold=score_threshold
-        )([boxes, classification])
-
-    prediction_model = models.Model(inputs=[image_input], outputs=detections, name='efficientdet_p')
+    detections = FilterDetections(
+        name='filtered_detections',
+        score_threshold=score_threshold
+    )([boxes, classification])
+    prediction_model = models.Model(inputs=[image_input, anchors_input], outputs=detections, name='efficientdet_p')
     return model, prediction_model
+
+
+
