@@ -62,6 +62,8 @@ def inject_tfkeras_modules(func):
 
 def init_keras_custom_objects():
     import keras
+    import sys
+    sys.path.append("../")
     from .. import efficientnet as model
 
     custom_objects = {
@@ -74,6 +76,9 @@ def init_keras_custom_objects():
 
 def init_tfkeras_custom_objects():
     import tensorflow.keras as tfkeras
+    import sys
+    sys.path.append("../")
+
     from .. import efficientnet as model
 
     custom_objects = {
@@ -94,82 +99,18 @@ def preprocess_image(image, image_size):
         scale = image_size / image_width
         resized_height = int(image_height * scale)
         resized_width = image_size
-    
     image = cv2.resize(image, (resized_width, resized_height))
     new_image = np.ones((image_size, image_size, 3), dtype=np.float32) * 128.
     offset_h = (image_size - resized_height) // 2
     offset_w = (image_size - resized_width) // 2
     new_image[offset_h:offset_h + resized_height, offset_w:offset_w + resized_width] = image.astype(np.float32)
     new_image /= 255.
-    
     mean = [0.485, 0.456, 0.406]
     std = [0.229, 0.224, 0.225]
-    
-    for i in range(3):
-        new_image[..., i] -= mean[i]
-        new_image[..., i] /= std[i]
-    
+    new_image[..., 0] -= mean[0]
+    new_image[..., 1] -= mean[1]
+    new_image[..., 2] -= mean[2]
+    new_image[..., 0] /= std[0]
+    new_image[..., 1] /= std[1]
+    new_image[..., 2] /= std[2]
     return new_image, scale, offset_h, offset_w
-
-
-def rotate_image(image):
-    rotate_degree = np.random.uniform(low=-45, high=45)
-    h, w = image.shape[:2]
-    # Compute the rotation matrix.
-    M = cv2.getRotationMatrix2D(center=(w / 2, h / 2),
-                                angle=rotate_degree,
-                                scale=1)
-
-    # Get the sine and cosine from the rotation matrix.
-    abs_cos_angle = np.abs(M[0, 0])
-    abs_sin_angle = np.abs(M[0, 1])
-
-    # Compute the new bounding dimensions of the image.
-    new_w = int(h * abs_sin_angle + w * abs_cos_angle)
-    new_h = int(h * abs_cos_angle + w * abs_sin_angle)
-
-    # Adjust the rotation matrix to take into account the translation.
-    M[0, 2] += new_w // 2 - w // 2
-    M[1, 2] += new_h // 2 - h // 2
-
-    # Rotate the image.
-    image = cv2.warpAffine(image, M=M, dsize=(new_w, new_h), flags=cv2.INTER_CUBIC,
-                           borderMode=cv2.BORDER_CONSTANT,
-                           borderValue=(128, 128, 128))
-
-    return image
-
-
-def reorder_vertexes(vertexes):
-    """
-    reorder vertexes as the paper shows, (top, right, bottom, left)
-    Args:
-        vertexes: np.array (4, 2), should be in clockwise
-
-    Returns:
-
-    """
-    assert vertexes.shape == (4, 2)
-    xmin, ymin = np.min(vertexes, axis=0)
-    xmax, ymax = np.max(vertexes, axis=0)
-
-    # determine the first point with the smallest y,
-    # if two vertexes has same y, choose that with smaller x,
-    ordered_idxes = np.argsort(vertexes, axis=0)
-    ymin1_idx = ordered_idxes[0, 1]
-    ymin2_idx = ordered_idxes[1, 1]
-    if vertexes[ymin1_idx, 1] == vertexes[ymin2_idx, 1]:
-        if vertexes[ymin1_idx, 0] <= vertexes[ymin2_idx, 0]:
-            first_vertex_idx = ymin1_idx
-        else:
-            first_vertex_idx = ymin2_idx
-    else:
-        first_vertex_idx = ymin1_idx
-    ordered_idxes = [(first_vertex_idx + i) % 4 for i in range(4)]
-    ordered_vertexes = vertexes[ordered_idxes]
-    # drag the point to the corresponding edge
-    ordered_vertexes[0, 1] = ymin
-    ordered_vertexes[1, 0] = xmax
-    ordered_vertexes[2, 1] = ymax
-    ordered_vertexes[3, 0] = xmin
-    return ordered_vertexes
