@@ -16,14 +16,16 @@ limitations under the License.
 
 import keras
 import tensorflow as tf
-import initializers
-import layers
-from utils.anchors import AnchorParameters
-from models import assert_training_model
-from fsaf_layers import LevelSelect, FSAFTarget, Locations, RegressBoxes
-from losses import focal_with_mask, iou_with_mask
+import sys
+sys.path.append("../")
+from .. import initializers
+from .. import layers
+from ..utils.anchors import AnchorParameters
+from . import assert_training_model
+from ..fsaf_layers import LevelSelect, FSAFTarget, Locations, RegressBoxes
+from ..losses import focal_with_mask, iou_with_mask
 import keras.backend as K
-import configure
+from .. import configure
 
 
 def default_classification_model(
